Key

#[repr(u32)]
pub enum Key {
Show 204 variants Unknown = 0, A = 458_756, B = 458_757, C = 458_758, D = 458_759, E = 458_760, F = 458_761, G = 458_762, H = 458_763, I = 458_764, J = 458_765, K = 458_766, L = 458_767, M = 458_768, N = 458_769, O = 458_770, P = 458_771, Q = 458_772, R = 458_773, S = 458_774, T = 458_775, U = 458_776, V = 458_777, W = 458_778, X = 458_779, Y = 458_780, Z = 458_781, Key1 = 458_782, Key2 = 458_783, Key3 = 458_784, Key4 = 458_785, Key5 = 458_786, Key6 = 458_787, Key7 = 458_788, Key8 = 458_789, Key9 = 458_790, Key0 = 458_791, Enter = 458_792, Escape = 458_793, Backspace = 458_794, Tab = 458_795, Space = 458_796, Minus = 458_797, Equals = 458_798, LeftBrace = 458_799, RightBrace = 458_800, Backslash = 458_801, NonUsHash = 458_802, Semicolon = 458_803, Apostrophe = 458_804, GraveAccent = 458_805, Comma = 458_806, Dot = 458_807, Slash = 458_808, CapsLock = 458_809, F1 = 458_810, F2 = 458_811, F3 = 458_812, F4 = 458_813, F5 = 458_814, F6 = 458_815, F7 = 458_816, F8 = 458_817, F9 = 458_818, F10 = 458_819, F11 = 458_820, F12 = 458_821, PrintScreen = 458_822, ScrollLock = 458_823, Pause = 458_824, Insert = 458_825, Home = 458_826, PageUp = 458_827, Delete = 458_828, End = 458_829, PageDown = 458_830, Right = 458_831, Left = 458_832, Down = 458_833, Up = 458_834, NumLock = 458_835, KeypadSlash = 458_836, KeypadAsterisk = 458_837, KeypadMinus = 458_838, KeypadPlus = 458_839, KeypadEnter = 458_840, Keypad1 = 458_841, Keypad2 = 458_842, Keypad3 = 458_843, Keypad4 = 458_844, Keypad5 = 458_845, Keypad6 = 458_846, Keypad7 = 458_847, Keypad8 = 458_848, Keypad9 = 458_849, Keypad0 = 458_850, KeypadDot = 458_851, NonUsBackslash = 458_852, KeypadEquals = 458_855, Menu = 458_870, LeftCtrl = 458_976, LeftShift = 458_977, LeftAlt = 458_978, LeftMeta = 458_979, RightCtrl = 458_980, RightShift = 458_981, RightAlt = 458_982, RightMeta = 458_983, Mute = 458_879, VolumeDown = 458_881, VolumeUp = 458_880, PlayPause = 786_637, MediaMute = 786_658, MediaVolumeIncrement = 786_665, MediaVolumeDecrement = 786_666, AcBack = 786_980, AcRefresh = 786_983, AcFullScreenView = 786_992, AcSelectTaskApplication = 786_850, BrightnessDown = 786_543, BrightnessUp = 786_544, Assistant = 4_294_901_761, Power = 4_294_901_762, Sleep = 4_294_901_763, Unknown0055 = 4_294_901_845, Unknown0056 = 4_294_901_846, Unknown0059 = 4_294_901_849, Unknown005C = 4_294_901_852, Unknown005D = 4_294_901_853, Unknown005E = 4_294_901_854, Unknown0079 = 4_294_901_881, Unknown007A = 4_294_901_882, Unknown007B = 4_294_901_883, Unknown007C = 4_294_901_884, Unknown0085 = 4_294_901_893, Unknown0087 = 4_294_901_895, Unknown0089 = 4_294_901_897, Unknown009C = 4_294_901_916, Unknown009F = 4_294_901_919, Unknown00A0 = 4_294_901_920, Unknown00A2 = 4_294_901_922, Unknown00A3 = 4_294_901_923, Unknown00A5 = 4_294_901_925, Unknown00A6 = 4_294_901_926, Unknown00A7 = 4_294_901_927, Unknown00A8 = 4_294_901_928, Unknown00A9 = 4_294_901_929, Unknown00Ad = 4_294_901_933, Unknown00B1 = 4_294_901_937, Unknown00B2 = 4_294_901_938, Unknown00B3 = 4_294_901_939, Unknown00B4 = 4_294_901_940, Unknown00C9 = 4_294_901_961, Unknown00Cf = 4_294_901_967, Unknown00D0 = 4_294_901_968, Unknown00D4 = 4_294_901_972, Unknown00E2 = 4_294_901_986, Unknown0120 = 4_294_902_048, Unknown0121 = 4_294_902_049, Unknown0122 = 4_294_902_050, Unknown0123 = 4_294_902_051, Unknown0124 = 4_294_902_052, Unknown0125 = 4_294_902_053, Unknown0126 = 4_294_902_054, Unknown0127 = 4_294_902_055, Unknown0128 = 4_294_902_056, Unknown0129 = 4_294_902_057, Unknown012A = 4_294_902_058, Unknown012B = 4_294_902_059, Unknown012C = 4_294_902_060, Unknown012D = 4_294_902_061, Unknown012E = 4_294_902_062, Unknown012F = 4_294_902_063, Unknown0130 = 4_294_902_064, Unknown0131 = 4_294_902_065, Unknown0132 = 4_294_902_066, Unknown0133 = 4_294_902_067, Unknown0134 = 4_294_902_068, Unknown0135 = 4_294_902_069, Unknown0136 = 4_294_902_070, Unknown0137 = 4_294_902_071, Unknown0138 = 4_294_902_072, Unknown0139 = 4_294_902_073, Unknown013A = 4_294_902_074, Unknown013B = 4_294_902_075, Unknown013C = 4_294_902_076, Unknown013D = 4_294_902_077, Unknown013E = 4_294_902_078, Unknown0161 = 4_294_902_113, Unknown016A = 4_294_902_122, Unknown016E = 4_294_902_126, Unknown0172 = 4_294_902_130, Unknown0179 = 4_294_902_137, Unknown018E = 4_294_902_158, Unknown018F = 4_294_902_159, Unknown0190 = 4_294_902_160, Unknown0191 = 4_294_902_161, Unknown0192 = 4_294_902_162, Unknown0193 = 4_294_902_163, Unknown0195 = 4_294_902_165, Unknown01D0 = 4_294_902_224, Unknown020A = 4_294_902_282, Unknown020B = 4_294_902_283, UnknownOrdinal_(u32),
}
A Fuchsia key represents a control that can be pressed or released such as a key or a button on a keyboard or another input device.

The ordinal index for enum elements is derived from the USB HID Usage Tables at the time of definition. It is a 32 bit unsigned integer representing the USB HID Usage where the low 16 bits are the USB HID Usage ID and the high 16 bits are the USB HID Usage Page.

The descriptions for each value in the enum assume a US English keyboard layout. Actual behavior varies by layout.

Variants



Unknown = 0



A = 458_756



B = 458_757



C = 458_758



D = 458_759



E = 458_760



F = 458_761



G = 458_762



H = 458_763



I = 458_764



J = 458_765



K = 458_766



L = 458_767



M = 458_768



N = 458_769



O = 458_770



P = 458_771



Q = 458_772



R = 458_773



S = 458_774



T = 458_775



U = 458_776



V = 458_777



W = 458_778



X = 458_779



Y = 458_780



Z = 458_781



Key1 = 458_782



Key2 = 458_783



Key3 = 458_784



Key4 = 458_785



Key5 = 458_786



Key6 = 458_787



Key7 = 458_788



Key8 = 458_789



Key9 = 458_790



Key0 = 458_791



Enter = 458_792



Escape = 458_793



Backspace = 458_794



Tab = 458_795



Space = 458_796



Minus = 458_797



Equals = 458_798



LeftBrace = 458_799



RightBrace = 458_800



Backslash = 458_801



NonUsHash = 458_802



Semicolon = 458_803



Apostrophe = 458_804



GraveAccent = 458_805



Comma = 458_806



Dot = 458_807



Slash = 458_808



CapsLock = 458_809



F1 = 458_810



F2 = 458_811



F3 = 458_812



F4 = 458_813



F5 = 458_814



F6 = 458_815



F7 = 458_816



F8 = 458_817



F9 = 458_818



F10 = 458_819



F11 = 458_820



F12 = 458_821



PrintScreen = 458_822



ScrollLock = 458_823



Pause = 458_824



Insert = 458_825



Home = 458_826



PageUp = 458_827



Delete = 458_828



End = 458_829



PageDown = 458_830



Right = 458_831



Left = 458_832



Down = 458_833



Up = 458_834



NumLock = 458_835



KeypadSlash = 458_836



KeypadAsterisk = 458_837



KeypadMinus = 458_838



KeypadPlus = 458_839



KeypadEnter = 458_840



Keypad1 = 458_841



Keypad2 = 458_842



Keypad3 = 458_843



Keypad4 = 458_844



Keypad5 = 458_845



Keypad6 = 458_846



Keypad7 = 458_847



Keypad8 = 458_848



Keypad9 = 458_849



Keypad0 = 458_850



KeypadDot = 458_851



NonUsBackslash = 458_852



KeypadEquals = 458_855



Menu = 458_870



LeftCtrl = 458_976



LeftShift = 458_977



LeftAlt = 458_978



LeftMeta = 458_979



RightCtrl = 458_980



RightShift = 458_981



RightAlt = 458_982



RightMeta = 458_983



Mute = 458_879



VolumeDown = 458_881



VolumeUp = 458_880



PlayPause = 786_637



MediaMute = 786_658



MediaVolumeIncrement = 786_665



MediaVolumeDecrement = 786_666



AcBack = 786_980



AcRefresh = 786_983



AcFullScreenView = 786_992



AcSelectTaskApplication = 786_850



BrightnessDown = 786_543



BrightnessUp = 786_544



Assistant = 4_294_901_761



Power = 4_294_901_762



Sleep = 4_294_901_763



Unknown0055 = 4_294_901_845



Unknown0056 = 4_294_901_846



Unknown0059 = 4_294_901_849



Unknown005C = 4_294_901_852



Unknown005D = 4_294_901_853



Unknown005E = 4_294_901_854



Unknown0079 = 4_294_901_881



Unknown007A = 4_294_901_882



Unknown007B = 4_294_901_883



Unknown007C = 4_294_901_884



Unknown0085 = 4_294_901_893



Unknown0087 = 4_294_901_895



Unknown0089 = 4_294_901_897



Unknown009C = 4_294_901_916



Unknown009F = 4_294_901_919



Unknown00A0 = 4_294_901_920



Unknown00A2 = 4_294_901_922



Unknown00A3 = 4_294_901_923



Unknown00A5 = 4_294_901_925



Unknown00A6 = 4_294_901_926



Unknown00A7 = 4_294_901_927



Unknown00A8 = 4_294_901_928



Unknown00A9 = 4_294_901_929



Unknown00Ad = 4_294_901_933



Unknown00B1 = 4_294_901_937



Unknown00B2 = 4_294_901_938



Unknown00B3 = 4_294_901_939



Unknown00B4 = 4_294_901_940



Unknown00C9 = 4_294_901_961



Unknown00Cf = 4_294_901_967



Unknown00D0 = 4_294_901_968



Unknown00D4 = 4_294_901_972



Unknown00E2 = 4_294_901_986



Unknown0120 = 4_294_902_048



Unknown0121 = 4_294_902_049



Unknown0122 = 4_294_902_050



Unknown0123 = 4_294_902_051



Unknown0124 = 4_294_902_052



Unknown0125 = 4_294_902_053



Unknown0126 = 4_294_902_054



Unknown0127 = 4_294_902_055



Unknown0128 = 4_294_902_056



Unknown0129 = 4_294_902_057



Unknown012A = 4_294_902_058



Unknown012B = 4_294_902_059



Unknown012C = 4_294_902_060



Unknown012D = 4_294_902_061



Unknown012E = 4_294_902_062



Unknown012F = 4_294_902_063



Unknown0130 = 4_294_902_064



Unknown0131 = 4_294_902_065



Unknown0132 = 4_294_902_066



Unknown0133 = 4_294_902_067



Unknown0134 = 4_294_902_068



Unknown0135 = 4_294_902_069



Unknown0136 = 4_294_902_070



Unknown0137 = 4_294_902_071



Unknown0138 = 4_294_902_072



Unknown0139 = 4_294_902_073



Unknown013A = 4_294_902_074



Unknown013B = 4_294_902_075



Unknown013C = 4_294_902_076



Unknown013D = 4_294_902_077



Unknown013E = 4_294_902_078



Unknown0161 = 4_294_902_113



Unknown016A = 4_294_902_122



Unknown016E = 4_294_902_126



Unknown0172 = 4_294_902_130



Unknown0179 = 4_294_902_137



Unknown018E = 4_294_902_158



Unknown018F = 4_294_902_159



Unknown0190 = 4_294_902_160



Unknown0191 = 4_294_902_161



Unknown0192 = 4_294_902_162



Unknown0193 = 4_294_902_163



Unknown0195 = 4_294_902_165



Unknown01D0 = 4_294_902_224



Unknown020A = 4_294_902_282



Unknown020B = 4_294_902_283



UnknownOrdinal_(u32)